<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapYManual</name>
    <message>
        <location filename="../SnapYManualInit.js" line="+2"/>
        <source>&amp;Y/X from Points</source>
        <translation>&amp;Y/X z punktów</translation>
    </message>
</context>
</TS>
